=========
Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog`_, and this project adheres to `Semantic Versioning`_.

`Unreleased`_
-------------

`0.5.0`_ - 2022-01-05
---------------------

Added
^^^^^
* Added python310 support

Removed
^^^^^^^
* Dropped python36 support

`0.4.0`_ - 2020-02-26
---------------------

Removed
^^^^^^^
* Removed the pastel dependency

`0.3.1`_ - 2019-09-30
---------------------

Added
^^^^^
* Made the settings path configurable
* Made the report of the test results more fine-grained

`0.3.0`_ - 2019-09-24
---------------------

Added
^^^^^
* Added database tests

`0.2.1`_ - 2019-09-24
---------------------

Fixed
^^^^^
* Fixed a connection issue

`0.2.0`_ - 2019-09-24
---------------------

Added
^^^^^
* Added database migrations

`0.1.0`_ - 2019-09-18
---------------------

Added
^^^^^
* Added the initial project structure


.. _`unreleased`: https://github.com/spapanik/saitama/compare/v0.5.0...master
.. _`0.4.0`: https://github.com/spapanik/saitama/compare/v0.4.0...v0.5.0
.. _`0.4.0`: https://github.com/spapanik/saitama/compare/v0.3.1...v0.4.0
.. _`0.3.1`: https://github.com/spapanik/saitama/compare/v0.3.0...v0.3.1
.. _`0.3.0`: https://github.com/spapanik/saitama/compare/v0.2.1...v0.3.0
.. _`0.2.1`: https://github.com/spapanik/saitama/compare/v0.2.0...v0.2.1
.. _`0.2.0`: https://github.com/spapanik/saitama/compare/v0.1.0...v0.2.0
.. _`0.1.0`: https://github.com/spapanik/saitama/releases/tag/v0.1.0

.. _`Keep a Changelog`: https://keepachangelog.com/en/1.0.0/
.. _`Semantic Versioning`: https://semver.org/spec/v2.0.0.html
